/*========================================================================================================
 * Arcade1StickDrive.h
 *========================================================================================================
 *
 * File Description:
 *
 * This extends the ArcadeDrive to use the right axis for both throttle and steer inputs.
 *
 * Thus, the right axis forward/backward will control speed (throttle) and the right axis
 * left/right will will control direction (steering). The speed control (throttle) will
 * get a cubic profile while the steer control will be direct (linear).
 *
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

#ifndef SRC_Arcade1StickDrive_H_
#define SRC_Arcade1StickDrive_H_


//  Team 302 includes
#include <ArcadeDrive.h>            // Base class

class Arcade1StickDrive: public ArcadeDrive
{
    public:
        //--------------------------------------------------------------------
        // Method:      Arcade1StickDrive <<constructor>>
        // Description: This method creates and initializes the objects
        //--------------------------------------------------------------------
        Arcade1StickDrive();      // constructor

        //--------------------------------------------------------------------
        // Method:      Init
        // Description: This method will initialize the values.
        // Returns:     void
        //--------------------------------------------------------------------
        void Init() override;

        //--------------------------------------------------------------------
        // Method:      GetIdentifier
        // Description: This gets the name that identifies the drive mode..
        // Returns:     const char*         identifier for the drive
        //--------------------------------------------------------------------
        const char* GetIdentifier() const override;

        //--------------------------------------------------------------------
        // Method:      ~Arcade1StickDrive <<destructor>>
        // Description: This method is called to delete these objects
        //--------------------------------------------------------------------
        virtual ~Arcade1StickDrive() = default; // destructor

    protected:


    private:

        // Default methods we don't want the compiler to implement for us
        Arcade1StickDrive( const Arcade1StickDrive& ) = delete;
        Arcade1StickDrive& operator= ( const Arcade1StickDrive& ) = delete;
        explicit Arcade1StickDrive( Arcade1StickDrive* other ) = delete;


};

#endif /* SRC_Arcade1StickDrive_H_ */
