/*========================================================================================================
 * DigitalInput.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This class extends the RunMotorsDrive class that runs the drive motors using a digital input to
 * control the robot.  When the digital input is true, the robot will move at full speed forward
 * and when it is false, it will stop the robot.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

//  WPILIB includes
#include <DigitalInput.h>

// Team 302 includes
#include <DigitalInputDrive.h>          // This class
#include <RunMotorsDrive.h>             // Base class
#include <RobotMap.h>                   // Definition of ports

//--------------------------------------------------------------------
// Method:      DigitalInputDrive  <<constructor>>
// Description: Create and initialize object
//--------------------------------------------------------------------
DigitalInputDrive::DigitalInputDrive() : RunMotorsDrive( 0.0 ) ,
                                         m_sensor( nullptr )
{
    m_sensor = new DigitalInput( DIGITAL_INPUT_SENSOR_PORT );
    Init();
}

//--------------------------------------------------------------------
// Method:      Init
// Description: This method will initialize the values.
// Returns:     void
//--------------------------------------------------------------------
void DigitalInputDrive::Init()
{
    SetCoastMode();
}

//--------------------------------------------------------------------
// Method:      HasTarget
// Description: This indicates if this drive mode doesn't have a target
// Returns:     false = doesn't have a target
//--------------------------------------------------------------------
bool DigitalInputDrive::HasTarget() const
{
    return false;
}


//--------------------------------------------------------------------
// Method:      SetTarget
// Description: This sets the target for the drive class.
// Returns:     void
//--------------------------------------------------------------------
void DigitalInputDrive::SetTarget
(
    float   target
)
{
}

//--------------------------------------------------------------------
// Method:      DrivePeriodic
// Description: This method will be called during the periodic loop
//              to drive the robot.  It will interact with the digital
//              input to control whether to move the wheels or not.
// Returns:     false = this mode is never done
//--------------------------------------------------------------------
bool DigitalInputDrive::DrivePeriodic() const
{
    // TODO:    read the digital sensor using the Get method.  It returns
    //          a bool.  When the bool is true, run the motors at 1.0.
    //          When it is 0.0, stop the motors.
    //
    //          For an added challenge, update this program such that when
    //          the motors run, first they will move forward (1.0), then
    //          after stopping, the next time they run have them run in
    //          reverse (-1.0).  Repeat this cycle so that the next time they
    //          run the go forward again.
    bool on = m_sensor->Get();
    float motorInput =  0.0;
    // Update the motor speeds
    ChangeSpeed( motorInput );
    return false;
}


//--------------------------------------------------------------------
// Method:      GetIdentifier
// Description: This gets the name that identifies the drive mode..
// Returns:     const char*         identifier for the drive
//--------------------------------------------------------------------
const char* DigitalInputDrive::GetIdentifier() const
{
    return "Digital Input Drive";
}

//--------------------------------------------------------------------
// Method:      ~DigitalInputDrive  <<destructor>>
// Description: Clean up memory.
//--------------------------------------------------------------------
DigitalInputDrive::~DigitalInputDrive()
{
    delete m_sensor;
    m_sensor = nullptr;
}

