/*========================================================================================================
 * DigitalInput.h
 *========================================================================================================
 *
 * File Description:
 *
 * This class extends the RunMotorsDrive class that runs the drive motors using a digital input to
 * control the robot.  When the digital input is true, the robot will move at full speed forward
 * and when it is false, it will stop the robot.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

#ifndef SRC_DIGITALINPUTDRIVE_H_
#define SRC_DIGITALINPUTDRIVE_H_

//  WPILIB includes
#include <DigitalInput.h>

//  Team 302 includes
#include <RunMotorsDrive.h>             // Base class

class DigitalInputDrive: public RunMotorsDrive
{
    public:
        //--------------------------------------------------------------------
        // Method:      DigitalInputDrive  <<constructor>>
        // Description: Create and initialize object
        //--------------------------------------------------------------------
        DigitalInputDrive();        // constructor

        //--------------------------------------------------------------------
        // Method:      Init
        // Description: This method will initialize the values.
        // Returns:     void
        //--------------------------------------------------------------------
        void Init() override;

        //--------------------------------------------------------------------
        // Method:      HasTarget
        // Description: This indicates if this drive mode has a target
        //              such as time, distance, etc.
        // Returns:     true  = has a target
        //              false = doesn't have a target
        //--------------------------------------------------------------------
        bool HasTarget() const override;


        //--------------------------------------------------------------------
        // Method:      SetTarget
        // Description: This sets the target for the drive class.
        // Returns:     void
        //--------------------------------------------------------------------
        void SetTarget
        (
            float   target
        ) override;

        //--------------------------------------------------------------------
        // Method:      DrivePeriodic
        // Description: This method will be called during the periodic loop
        //              to drive the robot.  It will interact with the digital
        //              input to control whether to move the wheels or not.
        // Returns:     false = this mode is never done
        //--------------------------------------------------------------------
        bool DrivePeriodic() const override;

        //--------------------------------------------------------------------
        // Method:      GetIdentifier
        // Description: This gets the name that identifies the drive mode..
        // Returns:     const char*         identifier for the drive
        //--------------------------------------------------------------------
        const char* GetIdentifier() const override;

        //--------------------------------------------------------------------
        // Method:      ~DigitalInputDrive  <<destructor>>
        // Description: Clean up memory.
        //--------------------------------------------------------------------
        virtual ~DigitalInputDrive();       // destructor

    private:
        DigitalInput*   m_sensor;
};

#endif /* SRC_DIGITALINPUTDRIVE_H_ */
