/*========================================================================================================
 * DriveToDistance.h
 *========================================================================================================
 *
 * File Description:
 *
 * This implements the IDrive interface to drive the robot a specified distance.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

#ifndef SRC_DRIVETODISTANCE_H_
#define SRC_DRIVETODISTANCE_H_


//  Team 302 includes
#include <RunMotorsDrive.h>             // Base class

class DriveToDistance: public RunMotorsDrive
{
    public:

        //--------------------------------------------------------------------
        // Method:      DriveToDistance <<constructor>>
        // Description: This method creates/intializes the object.
        //--------------------------------------------------------------------
        DriveToDistance
        (
            float   distance            // <I> - distance to drive in feet
        );

        //--------------------------------------------------------------------
        // Method:      Init
        // Description: This method will initialize the values.
        // Returns:     void
        //--------------------------------------------------------------------
        void Init() override;

        //--------------------------------------------------------------------
        // Method:      HasTarget
        // Description: This indicates if this drive mode has a target
        //              such as time, distance, etc.
        // Returns:     true  = has a target
        //              false = doesn't have a target
        //--------------------------------------------------------------------
        bool HasTarget() const override;


        //--------------------------------------------------------------------
        // Method:      SetTarget
        // Description: This sets the target for the drive class.
        // Returns:     void
        //--------------------------------------------------------------------
        void SetTarget
        (
            float   target
        ) override;

        //--------------------------------------------------------------------
        // Method:      DrivePeriodic
        // Description: This method will be called during the periodic loop
        //              to drive the robot a specified distance.
        // Returns:     true  = reached the specified distance
        //              false = hasn't reached the specified distance
        //--------------------------------------------------------------------
        bool DrivePeriodic() const override;

        //--------------------------------------------------------------------
        // Method:      GetIdentifier
        // Description: This gets the name that identifies the drive mode..
        // Returns:     const char*         identifier for the drive
        //--------------------------------------------------------------------
        const char* GetIdentifier() const override;

        //--------------------------------------------------------------------
        // Method:      ~DriveToDistance  <<destructor>>
        // Description: Clean up memory.
        //--------------------------------------------------------------------
        virtual ~DriveToDistance();     // destructor
    private:
        float       m_targetDistance;       // distance to move the robot
        float       m_slowDownDistance;     // distance where we need to start slowing down


        // Default methods we don't want the compiler to implement for us
        DriveToDistance() = delete;
        DriveToDistance( const DriveToDistance& ) = delete;
        DriveToDistance& operator= ( const DriveToDistance& ) = delete;
        explicit DriveToDistance( DriveToDistance* other ) = delete;
};

#endif /* SRC_DRIVETODISTANCE_H_ */
