/*========================================================================================================
 * IChassisFactory.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This creates the IDrive classes.  It will retain what it has created, so that it only will create one
 * of any given type of IDrive.
 *
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

//  Team 302 includes
#include <IChassisFactory.h>			// This class
#include <IChassis.h>
#include <SoftwareTestChassis.h>
#include <Chassis.h>
#include <RobotMap.h>


IChassisFactory* IChassisFactory::m_instance = nullptr;	// initialize the instance variable to nullptr

//----------------------------------------------------------------------------------
// Method:		GetInstance
// Description:	If there isn't an instance of desired IDrive class, create it.
//				Otherwise, hand out the single instance.
// Returns:		IChassisFactory*	Drive class
//----------------------------------------------------------------------------------
IChassisFactory*	IChassisFactory::GetInstance()

{
	if ( IChassisFactory::m_instance == nullptr )
	{
		IChassisFactory::m_instance = new IChassisFactory();
	}
	return IChassisFactory::m_instance;
}

//--------------------------------------------------------------------
// Method:      IChassisFactory <<constructor>>
// Description: This method creates and initializes the objects
//--------------------------------------------------------------------
IChassisFactory::IChassisFactory() : m_chassis( nullptr )      // constructor
{
}

//----------------------------------------------------------------------------------
// Method:		GetIChassis
// Description:	If there isn't an instance of desired IChassis class, create it.
//				Otherwise, hand out the single instance.
// Returns:		IChassis*	Chassis class
//----------------------------------------------------------------------------------
IChassis*	IChassisFactory::GetIChassis()
{
	if ( m_chassis == nullptr )
	{
		switch ( ROBOT_CONFIGURATION )
		{
			case COMPETITION_BOT:
				break;

			case SOFTWARE_BOT:
				m_chassis = new SoftwareTestChassis();
				break;

			default:
				break;
		}
	}
	return m_chassis;
}

