/*========================================================================================================
 * NoMoveDrive.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This implements the IDrive interface to cause the robot not to move.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

// Team 302 includes
#include <NoMoveDrive.h>            // This class
#include <RunMotorsDrive.h>         // Parent class

//--------------------------------------------------------------------
// Method:      NoMoveDrive <<constructor>>
// Description: Get the chassis and then set the motor speeds to 0.0.
//--------------------------------------------------------------------
NoMoveDrive::NoMoveDrive() : RunMotorsDrive( 0.0 )
{
    Init();
}

//--------------------------------------------------------------------
// Method:      Init
// Description: This method will initialize the values.
// Returns:     void
//--------------------------------------------------------------------
void NoMoveDrive::Init()
{
    SetBrakeMode();
    ChangeSpeed( 0.0 );
}


//--------------------------------------------------------------------
// Method:      HasTarget
// Description: This indicates if this drive mode has a target
//              such as time, distance, etc.
// Returns:     true  = has a target
//              false = doesn't have a target
//--------------------------------------------------------------------
bool NoMoveDrive::HasTarget() const
{
    return false;
}


//--------------------------------------------------------------------
// Method:      GetIdentifier
// Description: This gets the name that identifies the drive mode..
// Returns:     const char*         identifier for the drive
//--------------------------------------------------------------------
const char* NoMoveDrive::GetIdentifier() const
{
    return "No Movement";
}
