/*========================================================================================================
 * RunMotorsDrive.cpp
 *========================================================================================================
 *
 * File Description:
 *
 * This implements the IDrive interface to run the drive motes at a constant value.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/

// Team 302 includes
#include <RunMotorsDrive.h>         // This class
#include <IDrive.h>                 // Parent interface
#include <IChassisFactory.h>        // Class constructs the correct chassis
#include <LimitValue.h>             // Utilities to restrict the range of values


//------------------------------------------------------------------------
// Method:      RunMotorsDrive <<constructor>>
// Description: This will construct and initialize the object
//------------------------------------------------------------------------
RunMotorsDrive::RunMotorsDrive
(
    float   speed           // <I> - value to set the motors to between -1.0 and 1.0
) : IDrive(),
    m_chassis(),
    m_speed( speed )
{
    m_chassis = IChassisFactory::GetInstance()->GetIChassis();
    Init();
}
RunMotorsDrive::RunMotorsDrive() : IDrive(),
                                   m_chassis( nullptr ),
                                   m_speed( 0.0 )
{
    m_chassis = IChassisFactory::GetInstance()->GetIChassis();
    Init();
}

//--------------------------------------------------------------------
// Method:      Init
// Description: This method will initialize the values.
// Returns:     void
//--------------------------------------------------------------------
void RunMotorsDrive::Init()
{
    ChangeSpeed( m_speed );
}

//--------------------------------------------------------------------
// Method:      HasTarget
// Description: This indicates if this drive mode doesn't have a target
// Returns:     false = doesn't have a target
//--------------------------------------------------------------------
bool RunMotorsDrive::HasTarget() const
{
    return false;
}


//--------------------------------------------------------------------
// Method:      SetTarget
// Description: This sets the target for the drive class.
// Returns:     void
//--------------------------------------------------------------------
void RunMotorsDrive::SetTarget
(
    float   target
)
{
}

//--------------------------------------------------------------------
// Method:      DrivePeriodic
// Description: This method will be called during the periodic loop
//              to run the motors at a constant value.
// Returns:     false = this is never done
//--------------------------------------------------------------------
bool RunMotorsDrive::DrivePeriodic() const
{
    return false;
}

//--------------------------------------------------------------------
// Method:      ChangeSpeed
// Description: This method will update the motor speed.
// Returns:     void
//--------------------------------------------------------------------
void RunMotorsDrive::ChangeSpeed
(
    float   speed           // <I> - value to set the motors to between -1.0 and 1.0
) const
{
    float limitedSpeed = LimitValue::ForceInRange( speed, -1.0, 1.0 );
    m_chassis->SetMotorSpeeds( limitedSpeed, limitedSpeed );
}


//----------------------------------------------------------------------------------
// Method:      SetBrakeMode
// Description: This will set the drive motors to brake mode
// Returns:     void
//----------------------------------------------------------------------------------
void RunMotorsDrive::SetBrakeMode() const
{
    m_chassis->SetBrakeMode();
}


//----------------------------------------------------------------------------------
// Method:      SetCoastMode
// Description: This will set the drive motors to coast mode
// Returns:     void
//----------------------------------------------------------------------------------
void RunMotorsDrive::SetCoastMode() const
{
    m_chassis->SetCoastMode();
}

//--------------------------------------------------------------------
// Method:      GetIdentifier
// Description: This gets the name that identifies the drive mode..
// Returns:     const char*         identifier for the drive
//--------------------------------------------------------------------
const char* RunMotorsDrive::GetIdentifier() const
{
    return "Run Motors";
}

