/*========================================================================================================
 * RunMotorsDrive.h
 *========================================================================================================
 *
 * File Description:
 *
 * This implements the IDrive interface to run the drive motes at a constant value.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/


#ifndef SRC_RUNMOTORSDRIVE_H_
#define SRC_RUNMOTORSDRIVE_H_

//  Team 302 includes
#include <IDrive.h>             // Interface being implemented
#include <IChassis.h>           // Class that controls the motors on the drive chassis


class RunMotorsDrive: public IDrive
{
    public:
        //------------------------------------------------------------------------
        // Method:      RunMotorsDrive <<constructor>>
        // Description: This will construct and initialize the object
        //------------------------------------------------------------------------
        RunMotorsDrive
        (
            float   speed           // <I> - value to set the motors to between -1.0 and 1.0
        );

        //--------------------------------------------------------------------
        // Method:      Init
        // Description: This method will initialize the values.
        // Returns:     void
        //--------------------------------------------------------------------
        void Init() override;

        //--------------------------------------------------------------------
        // Method:      HasTarget
        // Description: This indicates if this drive mode has a target
        //              such as time, distance, etc.
        // Returns:     true  = has a target
        //              false = doesn't have a target
        //--------------------------------------------------------------------
        bool HasTarget() const override;


        //--------------------------------------------------------------------
        // Method:      SetTarget
        // Description: This sets the target for the drive class.
        // Returns:     void
        //--------------------------------------------------------------------
        void SetTarget
        (
            float   target
        ) override;

        //--------------------------------------------------------------------
        // Method:      DrivePeriodic
        // Description: This method will be called during the periodic loop
        //              to run the motors at a constant value.
        // Returns:     false = this is never done
        //--------------------------------------------------------------------
        bool DrivePeriodic() const override;

        //--------------------------------------------------------------------
        // Method:      GetIdentifier
        // Description: This gets the name that identifies the drive mode..
        // Returns:     const char*         identifier for the drive
        //--------------------------------------------------------------------
        const char* GetIdentifier() const override;

        //--------------------------------------------------------------------
        // Method:      GetChassis
        // Description: Returns the chassie..
        // Returns:     Chassis*         drive chassis
        //--------------------------------------------------------------------
        inline IChassis* GetChassis() const { return m_chassis; }

    protected:
        RunMotorsDrive();

        //--------------------------------------------------------------------
        // Method:      ChangeSpeed
        // Description: This method will update the motor speed.
        // Returns:     void
        //--------------------------------------------------------------------
        void ChangeSpeed
        (
            float speed         // <I> - value to set the motors to between -1.0 and 1.0
        ) const;


        //----------------------------------------------------------------------------------
        // Method:      SetBrakeMode
        // Description: This will set the drive motors to brake mode
        // Returns:     void
        //----------------------------------------------------------------------------------
        void SetBrakeMode() const;


        //----------------------------------------------------------------------------------
        // Method:      SetCoastMode
        // Description: This will set the drive motors to coast mode
        // Returns:     void
        //----------------------------------------------------------------------------------
        void SetCoastMode() const;

        virtual ~RunMotorsDrive() = default;    // destructor - let the compiler define

    private:
        IChassis*       m_chassis;
        float           m_speed;

        // Default methods we don't want the compiler to implement for us
        RunMotorsDrive( const RunMotorsDrive& ) = delete;
        RunMotorsDrive& operator= ( const RunMotorsDrive& ) = delete;
        explicit RunMotorsDrive( RunMotorsDrive* other ) = delete;
};

#endif /* SRC_RUNMOTORSDRIVE_H_ */
