/*========================================================================================================
 * TimedDrive.h
 *========================================================================================================
 *
 * File Description:
 *
 * This class extends the RunMotorsDrive class that runs the drive motors for a specified amount of time.
 *========================================================================================================
 *  Modifications:
 *  Date            Name            Description of Change
 *  18-Oct-2016     Joe Witcpalek   Created File
 *========================================================================================================*/
#ifndef SRC_TIMEDDRIVE_H_
#define SRC_TIMEDDRIVE_H_

//  Team 302 includes
#include <RunMotorsDrive.h>             // Base class

class TimedDrive: public RunMotorsDrive
{
    public:

        //--------------------------------------------------------------------
        // Method:      TimedDrive <<constructor>>
        // Description: This method creates/intializes the object.
        //--------------------------------------------------------------------
        TimedDrive
        (
            float   time            // <I> - time to drive in seconds
        );

        //--------------------------------------------------------------------
        // Method:      Init
        // Description: This method will initialize the values.
        // Returns:     void
        //--------------------------------------------------------------------
        void Init() override;

        //--------------------------------------------------------------------
        // Method:      HasTarget
        // Description: This indicates if this drive mode has a target
        //              such as time, distance, etc.
        // Returns:     true  = has a target
        //              false = doesn't have a target
        //--------------------------------------------------------------------
        bool HasTarget() const override;


        //--------------------------------------------------------------------
        // Method:      SetTarget
        // Description: This sets the target for the drive class.
        // Returns:     void
        //--------------------------------------------------------------------
        void SetTarget
        (
            float   target
        ) override;

        //--------------------------------------------------------------------
        // Method:      DrivePeriodic
        // Description: This method will be called during the periodic loop
        //              to drive the robot for a specified period of time.
        // Returns:     true  = reached the specified time
        //              false = hasn't reached the specified time
        //--------------------------------------------------------------------
        bool DrivePeriodic() const override;

        //--------------------------------------------------------------------
        // Method:      GetIdentifier
        // Description: This gets the name that identifies the drive mode..
        // Returns:     const char*         identifier for the drive
        //--------------------------------------------------------------------
        const char* GetIdentifier() const override;

        virtual ~TimedDrive() = default;        // destructor
    private:
        //--------------------------------------------------------------------
        // Method:      CalculateLoopCount
        // Description: This method calculates the number of loops that needed
        //              to be run to meet the time criteria.  It then sets
        //              the m_targetLoopCount attribute and initializes the
        //              m_loopCount to 0.
        // Returns:     void
        //--------------------------------------------------------------------
        void CalculateLoopCount
        (
            float   time            // <I> - time to drive in seconds
        );

        // Class Attributes
        int m_targetLoopCount;  // Number of loops needed to run the desired time
        int m_loopCount;        // Counter for the number of loops completed


        // Default methods we don't want the compiler to implement for us
        TimedDrive() = delete;
        TimedDrive( const TimedDrive& ) = delete;
        TimedDrive& operator= ( const TimedDrive& ) = delete;
        explicit TimedDrive( TimedDrive* other ) = delete;
};

#endif /* SRC_TIMEDDRIVE_H_ */
